REM  This script will create the Oracle tables and Indexes for
REM  Project 2000. 
REM
REM  Tailor these variables for your database:
REM      1.  Connect to Oracle as the Table Owner.  This is most often
REM          the Oracle Userid of the Project Manager.  
REM
REM      2.  Change the tablespace name where the tables will be located
REM          in your database, if it is other than 'PROJECT_DATA'.
REM
REM      3.  Change the tablespace name for the index location, if 
REM          better performance may be a consideration.
REM
REM      4.  Alter storage parameters as needed. 
REM
REM
REM
REM
REM
 


DROP TABLE MSP_ASSIGNMENTS CASCADE CONSTRAINTS ; 

CREATE TABLE MSP_ASSIGNMENTS ( 
  RESERVED_DATA             CHAR(1), 
  PROJ_ID                   NUMBER(18), 
  ASSN_ACT_FINISH           DATE, 
  ASSN_ACT_START            DATE, 
  ASSN_ACWP                 FLOAT, 
  ASSN_BCWP                 FLOAT, 
  ASSN_BCWS                 FLOAT, 
  ASSN_RES_TYPE             NUMBER(2), 
  ASSN_IS_OVERALLOCATED     NUMBER(2), 
  ASSN_WORK_CONTOUR         NUMBER(6), 
  ASSN_START_VAR            NUMBER(18), 
  ASSN_FINISH_VAR           NUMBER(18), 
  ASSN_UPDATE_NEEDED        NUMBER(2), 
  EXT_EDIT_REF_DATA         VARCHAR2(255), 
  ASSN_UID                  NUMBER(18), 
  ASSN_HAS_LINKED_FIELDS    NUMBER(2), 
  ASSN_IS_CONFIRMED         NUMBER(2), 
  ASSN_RESPONSE_PENDING     NUMBER(2), 
  ASSN_HAS_NOTES            NUMBER(2), 
  ASSN_TEAM_STATUS_PENDING  NUMBER(2), 
  TASK_UID                  NUMBER(18), 
  RES_UID                   NUMBER(18), 
  ASSN_START_DATE           DATE, 
  ASSN_FINISH_DATE          DATE, 
  ASSN_DELAY                NUMBER(18), 
  ASSN_DELAY_FMT            NUMBER(6), 
  ASSN_LEVELING_DELAY       NUMBER(18), 
  ASSN_COST_RATE_TABLE      NUMBER(6), 
  ASSN_BASE_START           DATE, 
  ASSN_BASE_FINISH          DATE, 
  ASSN_MATERIAL_RATE_FMT    NUMBER(6), 
  ASSN_UNITS                FLOAT, 
  ASSN_WORK                 FLOAT, 
  ASSN_ACT_WORK             FLOAT, 
  ASSN_REG_WORK             FLOAT, 
  ASSN_REM_WORK             FLOAT, 
  ASSN_BASE_WORK            FLOAT, 
  ASSN_COST                 FLOAT, 
  ASSN_ACT_COST             FLOAT, 
  ASSN_REM_COST             FLOAT, 
  ASSN_BASE_COST            FLOAT, 
  ASSN_BASE_COST_PER_USE    FLOAT, 
  ASSN_OVT_WORK             FLOAT, 
  ASSN_ACT_OVT_WORK         FLOAT, 
  ASSN_REM_OVT_WORK         FLOAT, 
  ASSN_ACT_OVT_COST         FLOAT, 
  ASSN_REM_OVT_COST         FLOAT, 
  ASSN_RTF_NOTES            LONG RAW) 
 TABLESPACE PROJECT_DATA
   PCTFREE 10   PCTUSED 40
   INITRANS 1   MAXTRANS 255
 STORAGE ( 
   INITIAL 52K NEXT 680K PCTINCREASE 10
   MINEXTENTS 1 MAXEXTENTS 249 )
   NOCACHE; 


CREATE UNIQUE INDEX I_MSP_ASSIGNMENTS ON 
  MSP_ASSIGNMENTS(PROJ_ID, ASSN_UID) 
  TABLESPACE PROJECT_DATA PCTFREE 10
  STORAGE(INITIAL 52K NEXT 148K PCTINCREASE 10 ) ; 


DROP TABLE MSP_ATTRIBUTE_STRINGS CASCADE CONSTRAINTS ; 

CREATE TABLE MSP_ATTRIBUTE_STRINGS ( 
  RESERVED_DATA  CHAR(1), 
  PROJ_ID        NUMBER(18), 
  AS_ID          NUMBER(18), 
  AS_POSITION    NUMBER(18), 
  AS_VALUE       VARCHAR2(255)) 
 TABLESPACE PROJECT_DATA
   PCTFREE 10   PCTUSED 40
   INITRANS 1   MAXTRANS 255
 STORAGE ( 
   INITIAL 52K NEXT 52K PCTINCREASE 10
   MINEXTENTS 1 MAXEXTENTS 249 )
   NOCACHE; 


CREATE UNIQUE INDEX I_MSP_ATTRIBUTE_STRINGS ON 
  MSP_ATTRIBUTE_STRINGS(PROJ_ID, AS_ID, AS_POSITION) 
  TABLESPACE PROJECT_DATA PCTFREE 10
  STORAGE(INITIAL 52K NEXT 52K PCTINCREASE 10 ) ; 


DROP TABLE MSP_AVAILABILITY CASCADE CONSTRAINTS ; 

CREATE TABLE MSP_AVAILABILITY ( 
  RESERVED_DATA  CHAR(1), 
  PROJ_ID        NUMBER(18), 
  AVAIL_UID      NUMBER(18), 
  RES_UID        NUMBER(18), 
  AVAIL_FROM     DATE, 
  AVAIL_TO       DATE, 
  AVAIL_UNITS    FLOAT) 
 TABLESPACE PROJECT_DATA
   PCTFREE 10   PCTUSED 40
   INITRANS 1   MAXTRANS 255
 STORAGE ( 
   INITIAL 52K NEXT 52K PCTINCREASE 10
   MINEXTENTS 1 MAXEXTENTS 249 )
   NOCACHE; 


CREATE UNIQUE INDEX I_MSP_AVAILABILITY ON 
  MSP_AVAILABILITY(PROJ_ID, AVAIL_UID) 
  TABLESPACE PROJECT_DATA PCTFREE 10
  STORAGE(INITIAL 52K NEXT 52K PCTINCREASE 10 ) ; 


DROP TABLE MSP_CALENDARS CASCADE CONSTRAINTS ; 

CREATE TABLE MSP_CALENDARS ( 
  RESERVED_DATA    CHAR(1), 
  PROJ_ID          NUMBER(18), 
  CAL_UID          NUMBER(18), 
  CAL_BASE_UID     NUMBER(18), 
  RES_UID          NUMBER(18), 
  CAL_IS_BASE_CAL  NUMBER(2), 
  CAL_NAME         VARCHAR2(255)) 
 TABLESPACE PROJECT_DATA
   PCTFREE 10   PCTUSED 40
   INITRANS 1   MAXTRANS 255
 STORAGE ( 
   INITIAL 52K NEXT 52K PCTINCREASE 10
   MINEXTENTS 1 MAXEXTENTS 249 )
   NOCACHE; 


CREATE UNIQUE INDEX I_MSP_CALENDARS ON 
  MSP_CALENDARS(PROJ_ID, CAL_UID) 
  TABLESPACE PROJECT_DATA PCTFREE 10
  STORAGE(INITIAL 52K NEXT 52K PCTINCREASE 10 ) ; 


DROP TABLE MSP_CALENDAR_DATA CASCADE CONSTRAINTS ; 

CREATE TABLE MSP_CALENDAR_DATA ( 
  RESERVED_DATA        CHAR(1), 
  PROJ_ID              NUMBER(18), 
  CD_UID               NUMBER(18), 
  CAL_UID              NUMBER(18), 
  CD_DAY_OR_EXCEPTION  NUMBER(6), 
  CD_WORKING           NUMBER(6), 
  CD_FROM_DATE         DATE, 
  CD_TO_DATE           DATE, 
  CD_FROM_TIME1        DATE, 
  CD_TO_TIME1          DATE, 
  CD_FROM_TIME2        DATE, 
  CD_TO_TIME2          DATE, 
  CD_FROM_TIME3        DATE, 
  CD_TO_TIME3          DATE, 
  CD_FROM_TIME4        DATE, 
  CD_TO_TIME4          DATE, 
  CD_FROM_TIME5        DATE, 
  CD_TO_TIME5          DATE) 
 TABLESPACE PROJECT_DATA
   PCTFREE 10   PCTUSED 40
   INITRANS 1   MAXTRANS 255
 STORAGE ( 
   INITIAL 52K NEXT 52K PCTINCREASE 10
   MINEXTENTS 1 MAXEXTENTS 249 )
   NOCACHE; 


CREATE UNIQUE INDEX I_MSP_CALENDAR_DATA ON 
  MSP_CALENDAR_DATA(PROJ_ID, CD_UID) 
  TABLESPACE PROJECT_DATA PCTFREE 10
  STORAGE(INITIAL 52K NEXT 52K PCTINCREASE 10 ) ; 


DROP TABLE MSP_CODE_FIELDS CASCADE CONSTRAINTS ; 

CREATE TABLE MSP_CODE_FIELDS ( 
  PROJ_ID        NUMBER(18), 
  CODE_CATEGORY  NUMBER(18), 
  CODE_REF_UID   NUMBER(18), 
  CODE_FIELD_ID  NUMBER(18), 
  CODE_UID       NUMBER(18)) 
 TABLESPACE PROJECT_DATA
   PCTFREE 10   PCTUSED 40
   INITRANS 1   MAXTRANS 255
 STORAGE ( 
   INITIAL 52K NEXT 52K PCTINCREASE 10
   MINEXTENTS 1 MAXEXTENTS 249 )
   NOCACHE; 


CREATE UNIQUE INDEX I_MSP_CODE_FIELDS ON 
  MSP_CODE_FIELDS(PROJ_ID, CODE_CATEGORY, CODE_REF_UID, CODE_FIELD_ID) 
  TABLESPACE PROJECT_DATA PCTFREE 10
  STORAGE(INITIAL 52K NEXT 52K PCTINCREASE 10 ) ; 


DROP TABLE MSP_CONVERSIONS CASCADE CONSTRAINTS ; 

CREATE TABLE MSP_CONVERSIONS ( 
  STRING_TYPE_ID  NUMBER(18), 
  CONV_VALUE      NUMBER(18), 
  CONV_LANG_ID    NUMBER(18), 
  CONV_STRING     VARCHAR2(200)) 
 TABLESPACE PROJECT_DATA
   PCTFREE 10   PCTUSED 40
   INITRANS 1   MAXTRANS 255
 STORAGE ( 
   INITIAL 52K NEXT 52K PCTINCREASE 10
   MINEXTENTS 1 MAXEXTENTS 249 )
   NOCACHE; 


CREATE UNIQUE INDEX I_MSP_CONVERSIONS ON 
  MSP_CONVERSIONS(CONV_VALUE, CONV_LANG_ID, STRING_TYPE_ID) 
  TABLESPACE PROJECT_DATA PCTFREE 10
  STORAGE(INITIAL 52K NEXT 52K PCTINCREASE 10 ) ; 


DROP TABLE MSP_DATE_FIELDS CASCADE CONSTRAINTS ; 

CREATE TABLE MSP_DATE_FIELDS ( 
  PROJ_ID        NUMBER(18), 
  DATE_CATEGORY  NUMBER(18), 
  DATE_REF_UID   NUMBER(18), 
  DATE_FIELD_ID  NUMBER(18), 
  DATE_VALUE     DATE) 
 TABLESPACE PROJECT_DATA
   PCTFREE 10   PCTUSED 40
   INITRANS 1   MAXTRANS 255
 STORAGE ( 
   INITIAL 52K NEXT 52K PCTINCREASE 10
   MINEXTENTS 1 MAXEXTENTS 249 )
   NOCACHE; 


CREATE UNIQUE INDEX I_MSP_DATE_FIELDS ON 
  MSP_DATE_FIELDS(PROJ_ID, DATE_CATEGORY, DATE_REF_UID, DATE_FIELD_ID) 
  TABLESPACE PROJECT_DATA PCTFREE 10
  STORAGE(INITIAL 52K NEXT 52K PCTINCREASE 10 ) ; 


DROP TABLE MSP_DURATION_FIELDS CASCADE CONSTRAINTS ; 

CREATE TABLE MSP_DURATION_FIELDS ( 
  PROJ_ID       NUMBER(18), 
  DUR_CATEGORY  NUMBER(18), 
  DUR_REF_UID   NUMBER(18), 
  DUR_FIELD_ID  NUMBER(18), 
  DUR_VALUE     NUMBER(18), 
  DUR_FMT       NUMBER(6)) 
 TABLESPACE PROJECT_DATA
   PCTFREE 10   PCTUSED 40
   INITRANS 1   MAXTRANS 255
 STORAGE ( 
   INITIAL 52K NEXT 52K PCTINCREASE 10
   MINEXTENTS 1 MAXEXTENTS 249 )
   NOCACHE; 


CREATE UNIQUE INDEX I_MSP_DURATION_FIELDS ON 
  MSP_DURATION_FIELDS(PROJ_ID, DUR_CATEGORY, DUR_REF_UID, DUR_FIELD_ID) 
  TABLESPACE PROJECT_DATA PCTFREE 10
  STORAGE(INITIAL 52K NEXT 52K PCTINCREASE 10 ) ; 


DROP TABLE MSP_FIELD_ATTRIBUTES CASCADE CONSTRAINTS ; 

CREATE TABLE MSP_FIELD_ATTRIBUTES ( 
  RESERVED_DATA      CHAR(1), 
  PROJ_ID            NUMBER(18), 
  ATTRIB_FIELD_ID    NUMBER(18), 
  ATTRIB_ID          NUMBER(18), 
  ATTRIB_VALUE       NUMBER(18), 
  AS_ID              NUMBER(18), 
  ATTRIB_EXT_EDITED  NUMBER(2)) 
 TABLESPACE PROJECT_DATA
   PCTFREE 10   PCTUSED 40
   INITRANS 1   MAXTRANS 255
 STORAGE ( 
   INITIAL 52K NEXT 52K PCTINCREASE 10
   MINEXTENTS 1 MAXEXTENTS 249 )
   NOCACHE; 


CREATE UNIQUE INDEX I_MSP_FIELD_ATTRIBUTES ON 
  MSP_FIELD_ATTRIBUTES(PROJ_ID, ATTRIB_FIELD_ID, ATTRIB_ID) 
  TABLESPACE PROJECT_DATA PCTFREE 10
  STORAGE(INITIAL 52K NEXT 52K PCTINCREASE 10 ) ; 


DROP TABLE MSP_FLAG_FIELDS CASCADE CONSTRAINTS ; 

CREATE TABLE MSP_FLAG_FIELDS ( 
  PROJ_ID        NUMBER(18), 
  FLAG_CATEGORY  NUMBER(18), 
  FLAG_REF_UID   NUMBER(18), 
  FLAG_FIELD_ID  NUMBER(18), 
  FLAG_VALUE     NUMBER(2)) 
 TABLESPACE PROJECT_DATA
   PCTFREE 10   PCTUSED 40
   INITRANS 1   MAXTRANS 255
 STORAGE ( 
   INITIAL 52K NEXT 52K PCTINCREASE 10
   MINEXTENTS 1 MAXEXTENTS 249 )
   NOCACHE; 


CREATE UNIQUE INDEX I_MSP_FLAG_FIELDS ON 
  MSP_FLAG_FIELDS(PROJ_ID, FLAG_CATEGORY, FLAG_REF_UID, FLAG_FIELD_ID) 
  TABLESPACE PROJECT_DATA PCTFREE 10
  STORAGE(INITIAL 52K NEXT 52K PCTINCREASE 10 ) ; 


DROP TABLE MSP_LINKS CASCADE CONSTRAINTS ; 

CREATE TABLE MSP_LINKS ( 
  RESERVED_DATA       CHAR(1), 
  PROJ_ID             NUMBER(18), 
  EXT_EDIT_REF_DATA   VARCHAR2(255), 
  LINK_UID            NUMBER(18), 
  LINK_IS_CROSS_PROJ  NUMBER(2), 
  LINK_PRED_UID       NUMBER(18), 
  LINK_SUCC_UID       NUMBER(18), 
  LINK_TYPE           NUMBER(6), 
  LINK_LAG_FMT        NUMBER(6), 
  LINK_LAG            NUMBER(18)) 
 TABLESPACE PROJECT_DATA
   PCTFREE 10   PCTUSED 40
   INITRANS 1   MAXTRANS 255
 STORAGE ( 
   INITIAL 52K NEXT 108K PCTINCREASE 10
   MINEXTENTS 1 MAXEXTENTS 249 )
   NOCACHE; 


CREATE UNIQUE INDEX I_MSP_LINKS ON 
  MSP_LINKS(PROJ_ID, LINK_UID) 
  TABLESPACE PROJECT_DATA PCTFREE 10
  STORAGE(INITIAL 52K NEXT 76K PCTINCREASE 10 ) ; 


DROP TABLE MSP_NUMBER_FIELDS CASCADE CONSTRAINTS ; 

CREATE TABLE MSP_NUMBER_FIELDS ( 
  PROJ_ID       NUMBER(18), 
  NUM_CATEGORY  NUMBER(18), 
  NUM_REF_UID   NUMBER(18), 
  NUM_FIELD_ID  NUMBER(18), 
  NUM_VALUE     FLOAT) 
 TABLESPACE PROJECT_DATA
   PCTFREE 10   PCTUSED 40
   INITRANS 1   MAXTRANS 255
 STORAGE ( 
   INITIAL 52K NEXT 52K PCTINCREASE 10
   MINEXTENTS 1 MAXEXTENTS 249 )
   NOCACHE; 


CREATE UNIQUE INDEX I_MSP_NUMBER_FIELDS ON 
  MSP_NUMBER_FIELDS(PROJ_ID, NUM_CATEGORY, NUM_REF_UID, NUM_FIELD_ID) 
  TABLESPACE PROJECT_DATA PCTFREE 10
  STORAGE(INITIAL 52K NEXT 52K PCTINCREASE 10 ) ; 


DROP TABLE MSP_OUTLINE_CODES CASCADE CONSTRAINTS ; 

CREATE TABLE MSP_OUTLINE_CODES ( 
  RESERVED_DATA   CHAR(1), 
  PROJ_ID         NUMBER(18), 
  CODE_UID        NUMBER(18), 
  OC_PARENT       NUMBER(18), 
  OC_FIELD_ID     NUMBER(18), 
  OC_NAME         VARCHAR2(255), 
  OC_DESCRIPTION  VARCHAR2(255)) 
 TABLESPACE PROJECT_DATA
   PCTFREE 10   PCTUSED 40
   INITRANS 1   MAXTRANS 255
 STORAGE ( 
   INITIAL 52K NEXT 52K PCTINCREASE 10
   MINEXTENTS 1 MAXEXTENTS 249 )
   NOCACHE; 


CREATE UNIQUE INDEX I_MSP_OUTLINE_CODES ON 
  MSP_OUTLINE_CODES(PROJ_ID, CODE_UID) 
  TABLESPACE PROJECT_DATA PCTFREE 10
  STORAGE(INITIAL 52K NEXT 52K PCTINCREASE 10 ) ; 


DROP TABLE MSP_PROJECTS CASCADE CONSTRAINTS ; 

CREATE TABLE MSP_PROJECTS ( 
  PROJ_ID                         NUMBER(18), 
  PROJ_NAME                       VARCHAR2(255), 
  PROJ_PROP_AUTHOR                VARCHAR2(255), 
  PROJ_OPT_CALC_ACT_COSTS         NUMBER(2), 
  PROJ_PROP_CATEGORY              VARCHAR2(255), 
  PROJ_PROP_COMPANY               VARCHAR2(255), 
  PROJ_OPT_CRITICAL_SLACK_LIMIT   NUMBER(18), 
  PROJ_OPT_CURRENCY_DIGITS        NUMBER(6), 
  PROJ_OPT_CURRENCY_POSITION      NUMBER(6), 
  PROJ_OPT_CURRENCY_SYMBOL        VARCHAR2(20), 
  PROJ_OPT_NEW_ARE_EFFORT_DRIVEN  NUMBER(2), 
  PROJ_INFO_CURRENT_DATE          DATE, 
  PROJ_OPT_DEF_FINISH_TIME        DATE, 
  PROJ_OPT_DEF_FIX_COST_ACCRUAL   NUMBER(6), 
  PROJ_OPT_MINUTES_PER_DAY        NUMBER(18), 
  PROJ_OPT_MINUTES_PER_WEEK       NUMBER(18), 
  PROJ_OPT_DEF_OVT_RATE           FLOAT, 
  PROJ_OPT_DEF_STD_RATE           FLOAT, 
  PROJ_OPT_DEF_START_TIME         DATE, 
  PROJ_OPT_DEF_TASK_TYPE          NUMBER(6), 
  PROJ_OPT_DUR_ENTRY_FMT          NUMBER(6), 
  PROJ_INFO_FINISH_DATE           DATE, 
  PROJ_OPT_HONOR_CONSTRAINTS      NUMBER(2), 
  PROJ_PROP_KEYWORDS              VARCHAR2(255), 
  PROJ_LAST_SAVED                 DATE, 
  PROJ_PROP_MANAGER               VARCHAR2(255), 
  PROJ_OPT_MULT_CRITICAL_PATHS    NUMBER(2), 
  PROJ_CREATION_DATE              DATE, 
  PROJ_POOL_ATTACHED_TO           VARCHAR2(255), 
  PROJ_INFO_CAL_NAME              VARCHAR2(255), 
  PROJ_IS_RES_POOL                NUMBER(2), 
  PROJ_INFO_SCHED_FROM            NUMBER(6), 
  PROJ_OPT_SPLIT_IN_PROGRESS      NUMBER(2), 
  PROJ_OPT_SPREAD_ACT_COSTS       NUMBER(2), 
  PROJ_OPT_SPREAD_PCT_COMP        NUMBER(2), 
  PROJ_INFO_START_DATE            DATE, 
  PROJ_INFO_STATUS_DATE           DATE, 
  PROJ_PROP_SUBJECT               VARCHAR2(255), 
  PROJ_PROP_TITLE                 VARCHAR2(255), 
  PROJ_OPT_TASK_UPDATES_RES       NUMBER(2), 
  PROJ_OPT_WORK_ENTRY_FMT         NUMBER(6), 
  PROJ_OPT_CALC_SUB_AS_SUMMARY    NUMBER(2), 
  PROJ_OPT_WEEK_START_DAY         NUMBER(6), 
  PROJ_OPT_FY_START_MONTH         NUMBER(6), 
  PROJ_OPT_FY_USE_START_YR        NUMBER(2), 
  PROJ_OPT_DAYS_PER_MONTH         NUMBER(6), 
  PROJ_OPT_NEW_TASK_EST           NUMBER(2), 
  PROJ_OPT_SHOW_EST_DUR           NUMBER(2), 
  PROJ_OPT_EXPAND_TIMEPHASED      NUMBER(2), 
  PROJ_EXT_EDITED_DATE            NUMBER(2), 
  PROJ_EXT_EDITED_DUR             NUMBER(2), 
  PROJ_EXT_EDITED_NUM             NUMBER(2), 
  PROJ_EXT_EDITED_FLAG            NUMBER(2), 
  PROJ_EXT_EDITED_CODE            NUMBER(2), 
  PROJ_EXT_EDITED_TEXT            NUMBER(2), 
  PROJ_EXT_EDITED                 NUMBER(2), 
  PROJ_DATA_SOURCE                VARCHAR2(128), 
  PROJ_READ_ONLY                  VARCHAR2(10), 
  PROJ_READ_WRITE                 VARCHAR2(4), 
  PROJ_READ_COUNT                 VARCHAR2(10), 
  PROJ_LOCKED                     VARCHAR2(4), 
  PROJ_MACHINE_ID                 VARCHAR2(100), 
  RESERVED_BINARY_DATA            LONG RAW) 
 TABLESPACE PROJECT_DATA
   PCTFREE 10   PCTUSED 40
   INITRANS 1   MAXTRANS 255
 STORAGE ( 
   INITIAL 52K NEXT 1784K PCTINCREASE 10
   MINEXTENTS 1 MAXEXTENTS 249 )
   NOCACHE; 


CREATE UNIQUE INDEX I_MSP_PROJECTS ON 
  MSP_PROJECTS(PROJ_ID) 
  TABLESPACE PROJECT_DATA PCTFREE 10
  STORAGE(INITIAL 52K NEXT 52K PCTINCREASE 10 ) ; 

CREATE UNIQUE INDEX I_PROJ_NAME ON 
  MSP_PROJECTS(PROJ_NAME) 
  TABLESPACE PROJECT_DATA PCTFREE 10
  STORAGE(INITIAL 52K NEXT 52K PCTINCREASE 10 ) ; 


DROP TABLE MSP_RESOURCES CASCADE CONSTRAINTS ; 

CREATE TABLE MSP_RESOURCES ( 
  RESERVED_DATA            CHAR(1), 
  PROJ_ID                  NUMBER(18), 
  RES_ACWP                 FLOAT, 
  RES_BCWP                 FLOAT, 
  RES_BCWS                 FLOAT, 
  RES_NUM_OBJECTS          NUMBER(18), 
  EXT_EDIT_REF_DATA        VARCHAR2(255), 
  RES_UID                  NUMBER(18), 
  RES_ID                   NUMBER(18), 
  RES_HAS_LINKED_FIELDS    NUMBER(2), 
  RES_IS_OVERALLOCATED     NUMBER(2), 
  RES_TYPE                 NUMBER(2), 
  RES_HAS_NOTES            NUMBER(2), 
  RES_CAN_LEVEL            NUMBER(2), 
  RES_STD_RATE_FMT         NUMBER(6), 
  RES_OVT_RATE_FMT         NUMBER(6), 
  RES_ACCRUE_AT            NUMBER(6), 
  RES_WORKGROUP_MESSAGING  NUMBER(6), 
  RES_CAL_UID              NUMBER(18), 
  RES_AVAIL_FROM           DATE, 
  RES_AVAIL_TO             DATE, 
  RES_STD_RATE             FLOAT, 
  RES_OVT_RATE             FLOAT, 
  RES_MAX_UNITS            FLOAT, 
  RES_WORK                 FLOAT, 
  RES_ACT_WORK             FLOAT, 
  RES_BASE_WORK            FLOAT, 
  RES_OVT_WORK             FLOAT, 
  RES_COST_PER_USE         FLOAT, 
  RES_REM_WORK             FLOAT, 
  RES_REG_WORK             FLOAT, 
  RES_ACT_OVT_WORK         FLOAT, 
  RES_REM_OVT_WORK         FLOAT, 
  RES_PEAK                 FLOAT, 
  RES_ACT_COST             FLOAT, 
  RES_COST                 FLOAT, 
  RES_BASE_COST            FLOAT, 
  RES_REM_COST             FLOAT, 
  RES_OVT_COST             FLOAT, 
  RES_ACT_OVT_COST         FLOAT, 
  RES_REM_OVT_COST         FLOAT, 
  RES_NAME                 VARCHAR2(255), 
  RES_INITIALS             VARCHAR2(255), 
  RES_PHONETICS            VARCHAR2(255), 
  RES_MATERIAL_LABEL       VARCHAR2(255), 
  RES_RTF_NOTES            LONG RAW) 
 TABLESPACE PROJECT_DATA
   PCTFREE 10   PCTUSED 40
   INITRANS 1   MAXTRANS 255
 STORAGE ( 
   INITIAL 52K NEXT 84K PCTINCREASE 10
   MINEXTENTS 1 MAXEXTENTS 249 )
   NOCACHE; 


CREATE UNIQUE INDEX I_MSP_RESOURCES ON 
  MSP_RESOURCES(PROJ_ID, RES_UID) 
  TABLESPACE PROJECT_DATA PCTFREE 10
  STORAGE(INITIAL 52K NEXT 52K PCTINCREASE 10 ) ; 


DROP TABLE MSP_RESOURCE_RATES CASCADE CONSTRAINTS ; 

CREATE TABLE MSP_RESOURCE_RATES ( 
  RESERVED_DATA    CHAR(1), 
  PROJ_ID          NUMBER(18), 
  RR_UID           NUMBER(18), 
  RES_UID          NUMBER(18), 
  RR_RATE_TABLE    NUMBER(6), 
  RR_FROM_DATE     DATE, 
  RR_TO_DATE       DATE, 
  RR_STD_RATE      FLOAT, 
  RR_STD_RATE_FMT  NUMBER(6), 
  RR_OVT_RATE      FLOAT, 
  RR_OVT_RATE_FMT  NUMBER(6), 
  RR_PER_USE_COST  FLOAT) 
 TABLESPACE PROJECT_DATA
   PCTFREE 10   PCTUSED 40
   INITRANS 1   MAXTRANS 255
 STORAGE ( 
   INITIAL 52K NEXT 52K PCTINCREASE 10
   MINEXTENTS 1 MAXEXTENTS 249 )
   NOCACHE; 


CREATE UNIQUE INDEX I_MSP_RESOURCE_RATES ON 
  MSP_RESOURCE_RATES(PROJ_ID, RR_UID) 
  TABLESPACE PROJECT_DATA PCTFREE 10
  STORAGE(INITIAL 52K NEXT 52K PCTINCREASE 10 ) ; 


DROP TABLE MSP_STRING_TYPES CASCADE CONSTRAINTS ; 

CREATE TABLE MSP_STRING_TYPES ( 
  STRING_TYPE_ID  NUMBER(18), 
  STRING_LANG_ID  NUMBER(18), 
  STRING_TYPE     VARCHAR2(200)) 
 TABLESPACE PROJECT_DATA
   PCTFREE 10   PCTUSED 40
   INITRANS 1   MAXTRANS 255
 STORAGE ( 
   INITIAL 52K NEXT 52K PCTINCREASE 10
   MINEXTENTS 1 MAXEXTENTS 249 )
   NOCACHE; 


CREATE UNIQUE INDEX I_MSP_STRING_TYPES ON 
  MSP_STRING_TYPES(STRING_TYPE_ID, STRING_LANG_ID) 
  TABLESPACE PROJECT_DATA PCTFREE 10
  STORAGE(INITIAL 52K NEXT 52K PCTINCREASE 10 ) ; 


DROP TABLE MSP_TASKS CASCADE CONSTRAINTS ; 

CREATE TABLE MSP_TASKS ( 
  RESERVED_DATA                CHAR(1), 
  PROJ_ID                      NUMBER(18), 
  TASK_ACWP                    FLOAT, 
  TASK_BCWP                    FLOAT, 
  TASK_BCWS                    FLOAT, 
  TASK_DUR_VAR                 NUMBER(18), 
  TASK_FINISH_VAR              NUMBER(18), 
  TASK_OUTLINE_NUM             VARCHAR2(255), 
  TASK_START_VAR               NUMBER(18), 
  TASK_IS_OVERALLOCATED        NUMBER(2), 
  TASK_OVT_WORK                FLOAT, 
  TASK_VAC                     FLOAT, 
  TASK_REG_WORK                FLOAT, 
  TASK_NUM_OBJECTS             NUMBER(18), 
  TASK_TOTAL_SLACK             NUMBER(18), 
  EXT_EDIT_REF_DATA            VARCHAR2(255), 
  TASK_UID                     NUMBER(18), 
  TASK_ID                      NUMBER(18), 
  TASK_HAS_LINKED_FIELDS       NUMBER(2), 
  TASK_IS_MILESTONE            NUMBER(2), 
  TASK_IS_CRITICAL             NUMBER(2), 
  TASK_IS_SUMMARY              NUMBER(2), 
  TASK_IS_SUBPROJ              NUMBER(2), 
  TASK_IS_MARKED               NUMBER(2), 
  TASK_IGNORES_RES_CAL         NUMBER(2), 
  TASK_IS_ROLLED_UP            NUMBER(2), 
  TASK_IS_FROM_FINISH_SUBPROJ  NUMBER(2), 
  TASK_BAR_IS_HIDDEN           NUMBER(2), 
  TASK_IS_RECURRING            NUMBER(2), 
  TASK_IS_RECURRING_SUMMARY    NUMBER(2), 
  TASK_IS_EXTERNAL             NUMBER(2), 
  TASK_IS_EFFORT_DRIVEN        NUMBER(2), 
  TASK_IS_COLLAPSED            NUMBER(2), 
  TASK_HAS_NOTES               NUMBER(2), 
  TASK_IS_READONLY_SUBPROJ     NUMBER(2), 
  TASK_LEVELING_CAN_SPLIT      NUMBER(2), 
  TASK_LEVELING_ADJUSTS_ASSN   NUMBER(2), 
  TASK_DUR_IS_EST              NUMBER(2), 
  TASK_EARLY_FINISH            DATE, 
  TASK_LATE_START              DATE, 
  TASK_STOP_DATE               DATE, 
  TASK_RESUME_DATE             DATE, 
  TASK_FREE_SLACK              NUMBER(18), 
  TASK_OUTLINE_LEVEL           NUMBER(6), 
  TASK_DUR                     NUMBER(18), 
  TASK_DUR_FMT                 NUMBER(6), 
  TASK_ACT_DUR                 NUMBER(18), 
  TASK_REM_DUR                 NUMBER(18), 
  TASK_BASE_DUR                NUMBER(18), 
  TASK_BASE_DUR_FMT            NUMBER(6), 
  TASK_CONSTRAINT_TYPE         NUMBER(6), 
  TASK_LEVELING_DELAY          NUMBER(18), 
  TASK_LEVELING_DELAY_FMT      NUMBER(6), 
  TASK_START_DATE              DATE, 
  TASK_FINISH_DATE             DATE, 
  TASK_ACT_START               DATE, 
  TASK_ACT_FINISH              DATE, 
  TASK_BASE_START              DATE, 
  TASK_BASE_FINISH             DATE, 
  TASK_CONSTRAINT_DATE         DATE, 
  TASK_PRIORITY                NUMBER(6), 
  TASK_PCT_COMP                NUMBER(6), 
  TASK_PCT_WORK_COMP           NUMBER(6), 
  TASK_TYPE                    NUMBER(6), 
  TASK_FIXED_COST_ACCRUAL      NUMBER(6), 
  TASK_CREATION_DATE           DATE, 
  TASK_PRELEVELED_START        DATE, 
  TASK_PRELEVELED_FINISH       DATE, 
  TASK_EARLY_START             DATE, 
  TASK_LATE_FINISH             DATE, 
  TASK_CAL_UID                 NUMBER(18), 
  TASK_DEADLINE                DATE, 
  TASK_WORK                    FLOAT, 
  TASK_BASE_WORK               FLOAT, 
  TASK_ACT_WORK                FLOAT, 
  TASK_REM_WORK                FLOAT, 
  TASK_COST                    FLOAT, 
  TASK_FIXED_COST              FLOAT, 
  TASK_ACT_COST                FLOAT, 
  TASK_REM_COST                FLOAT, 
  TASK_BASE_COST               FLOAT, 
  TASK_ACT_OVT_WORK            FLOAT, 
  TASK_REM_OVT_WORK            FLOAT, 
  TASK_OVT_COST                FLOAT, 
  TASK_ACT_OVT_COST            FLOAT, 
  TASK_REM_OVT_COST            FLOAT, 
  TASK_WBS                     VARCHAR2(255), 
  TASK_NAME                    VARCHAR2(255), 
  TASK_WBS_RIGHTMOST_LEVEL     VARCHAR2(255), 
  TASK_RTF_NOTES               LONG RAW) 
 TABLESPACE PROJECT_DATA
   PCTFREE 10   PCTUSED 40
   INITRANS 1   MAXTRANS 255
 STORAGE ( 
   INITIAL 52K NEXT 748K PCTINCREASE 10
   MINEXTENTS 1 MAXEXTENTS 249 )
   NOCACHE; 


CREATE UNIQUE INDEX I_MSP_TASKS ON 
  MSP_TASKS(PROJ_ID, TASK_UID) 
  TABLESPACE PROJECT_DATA PCTFREE 10
  STORAGE(INITIAL 52K NEXT 96K PCTINCREASE 10 ) ; 


DROP TABLE MSP_TEXT_FIELDS CASCADE CONSTRAINTS ; 

CREATE TABLE MSP_TEXT_FIELDS ( 
  PROJ_ID        NUMBER(18), 
  TEXT_CATEGORY  NUMBER(18), 
  TEXT_REF_UID   NUMBER(18), 
  TEXT_FIELD_ID  NUMBER(18), 
  TEXT_VALUE     VARCHAR2(255)) 
 TABLESPACE PROJECT_DATA
   PCTFREE 10   PCTUSED 40
   INITRANS 1   MAXTRANS 255
 STORAGE ( 
   INITIAL 52K NEXT 132K PCTINCREASE 10
   MINEXTENTS 1 MAXEXTENTS 249 )
   NOCACHE; 


CREATE UNIQUE INDEX I_MSP_TEXT_FIELDS ON 
  MSP_TEXT_FIELDS(PROJ_ID, TEXT_CATEGORY, TEXT_REF_UID, TEXT_FIELD_ID) 
  TABLESPACE PROJECT_DATA PCTFREE 10
  STORAGE(INITIAL 52K NEXT 164K PCTINCREASE 10 ) ; 


DROP TABLE MSP_TIMEPHASED_DATA CASCADE CONSTRAINTS ; 

CREATE TABLE MSP_TIMEPHASED_DATA ( 
  RESERVED_DATA  CHAR(1), 
  PROJ_ID        NUMBER(18), 
  TD_UID         NUMBER(18), 
  TD_FIELD_ID    NUMBER(6), 
  TD_CATEGORY    NUMBER(6), 
  TD_REF_UID     NUMBER(18), 
  TD_START       DATE, 
  TD_FINISH      DATE, 
  TD_UNITS       NUMBER(6), 
  TD_VALUE1      FLOAT, 
  TD_VALUE2      FLOAT, 
  TD_VALUE3      FLOAT, 
  TD_VALUE4      FLOAT, 
  TD_VALUE5      FLOAT, 
  TD_VALUE6      FLOAT, 
  TD_VALUE7      FLOAT, 
  TD_EXT_EDITED  NUMBER(2)) 
 TABLESPACE PROJECT_DATA
   PCTFREE 10   PCTUSED 40
   INITRANS 1   MAXTRANS 255
 STORAGE ( 
   INITIAL 52K NEXT 52K PCTINCREASE 10
   MINEXTENTS 1 MAXEXTENTS 249 )
   NOCACHE; 


CREATE UNIQUE INDEX I_MSP_TIMEPHASED_DATA ON 
  MSP_TIMEPHASED_DATA(PROJ_ID, TD_UID) 
  TABLESPACE PROJECT_DATA PCTFREE 10
  STORAGE(INITIAL 52K NEXT 52K PCTINCREASE 10 ) ; 



insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743767,  1033, 'Task Number1');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743768,  1033, 'Task Number2');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743769,  1033, 'Task Number3');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743770,  1033, 'Task Number4');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743771,  1033, 'Task Number5');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743982,  1033, 'Task Number6');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743983,  1033, 'Task Number7');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743984,  1033, 'Task Number8');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743985,  1033, 'Task Number9');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743986,  1033, 'Task Number10');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743987,  1033, 'Task Number11');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743988,  1033, 'Task Number12');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743989,  1033, 'Task Number13');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743990,  1033, 'Task Number14');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743991,  1033, 'Task Number15');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743992,  1033, 'Task Number16');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743993,  1033, 'Task Number17');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743994,  1033, 'Task Number18');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743995,  1033, 'Task Number19');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743996,  1033, 'Task Number20');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743696,  1033, 'Task WBS');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743897,  1033, 'Task Hyperlink');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743898,  1033, 'Task Hyperlink Address');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743899,  1033, 'Task Hyperlink SubAddress');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743774,  1033, 'Task Notes');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743792,  1033, 'Task Contact');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743731,  1033, 'Task Text1');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743734,  1033, 'Task Text2');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743737,  1033, 'Task Text3');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743740,  1033, 'Task Text4');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743743,  1033, 'Task Text5');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743746,  1033, 'Task Text6');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743747,  1033, 'Task Text7');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743748,  1033, 'Task Text8');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743749,  1033, 'Task Text9');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743750,  1033, 'Task Text10');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743997,  1033, 'Task Text11');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743998,  1033, 'Task Text12');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743999,  1033, 'Task Text13');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188744000,  1033, 'Task Text14');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188744001,  1033, 'Task Text15');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188744002,  1033, 'Task Text16');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188744003,  1033, 'Task Text17');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188744004,  1033, 'Task Text18');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188744005,  1033, 'Task Text19');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188744006,  1033, 'Task Text20');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188744007,  1033, 'Task Text21');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188744008,  1033, 'Task Text22');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188744009,  1033, 'Task Text23');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188744010,  1033, 'Task Text24');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188744011,  1033, 'Task Text25');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188744012,  1033, 'Task Text26');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188744013,  1033, 'Task Text27');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188744014,  1033, 'Task Text28');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188744015,  1033, 'Task Text29');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188744016,  1033, 'Task Text30');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188744095,  1033, 'Task WbsMaxValue');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743706,  1033, 'Task Subproject File');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743732,  1033, 'Task Start1');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743733,  1033, 'Task Finish1');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743735,  1033, 'Task Start2');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743736,  1033, 'Task Finish2');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743738,  1033, 'Task Start3');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743739,  1033, 'Task Finish3');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743741,  1033, 'Task Start4');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743742,  1033, 'Task Finish4');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743744,  1033, 'Task Start5');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743745,  1033, 'Task Finish5');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743962,  1033, 'Task Start6');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743963,  1033, 'Task Finish6');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743964,  1033, 'Task Start7');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743965,  1033, 'Task Finish7');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743966,  1033, 'Task Start8');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743967,  1033, 'Task Finish8');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743968,  1033, 'Task Start9');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743969,  1033, 'Task Finish9');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743970,  1033, 'Task Start10');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743971,  1033, 'Task Finish10');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743945,  1033, 'Task Date1');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743946,  1033, 'Task Date2');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743947,  1033, 'Task Date3');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743948,  1033, 'Task Date4');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743949,  1033, 'Task Date5');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743950,  1033, 'Task Date6');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743951,  1033, 'Task Date7');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743952,  1033, 'Task Date8');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743953,  1033, 'Task Date9');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743954,  1033, 'Task Date10');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743783,  1033, 'Task Duration1');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743784,  1033, 'Task Duration2');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743785,  1033, 'Task Duration3');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743955,  1033, 'Task Duration4');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743956,  1033, 'Task Duration5');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743957,  1033, 'Task Duration6');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743958,  1033, 'Task Duration7');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743959,  1033, 'Task Duration8');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743960,  1033, 'Task Duration9');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743961,  1033, 'Task Duration10');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743786,  1033, 'Task Cost1');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743787,  1033, 'Task Cost2');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743788,  1033, 'Task Cost3');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743938,  1033, 'Task Cost4');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743939,  1033, 'Task Cost5');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743940,  1033, 'Task Cost6');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743941,  1033, 'Task Cost7');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743942,  1033, 'Task Cost8');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743943,  1033, 'Task Cost9');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743944,  1033, 'Task Cost10');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743752,  1033, 'Task Flag1');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743753,  1033, 'Task Flag2');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743754,  1033, 'Task Flag3');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743755,  1033, 'Task Flag4');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743756,  1033, 'Task Flag5');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743757,  1033, 'Task Flag6');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743758,  1033, 'Task Flag7');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743759,  1033, 'Task Flag8');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743760,  1033, 'Task Flag9');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743761,  1033, 'Task Flag10');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743972,  1033, 'Task Flag11');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743973,  1033, 'Task Flag12');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743974,  1033, 'Task Flag13');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743975,  1033, 'Task Flag14');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743976,  1033, 'Task Flag15');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743977,  1033, 'Task Flag16');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743978,  1033, 'Task Flag17');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743979,  1033, 'Task Flag18');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743980,  1033, 'Task Flag19');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188743981,  1033, 'Task Flag20');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188744096,  1033, 'Task Outline Code1');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188744098,  1033, 'Task Outline Code2');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188744100,  1033, 'Task Outline Code3');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188744102,  1033, 'Task Outline Code4');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188744104,  1033, 'Task Outline Code5');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188744106,  1033, 'Task Outline Code6');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188744108,  1033, 'Task Outline Code7');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188744110,  1033, 'Task Outline Code8');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188744112,  1033, 'Task Outline Code9');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 188744114,  1033, 'Task Outline Code10');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521008,  1033, 'Resource Number1');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521009,  1033, 'Resource Number2');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521010,  1033, 'Resource Number3');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521011,  1033, 'Resource Number4');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521012,  1033, 'Resource Number5');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521101,  1033, 'Resource Number6');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521102,  1033, 'Resource Number7');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521103,  1033, 'Resource Number8');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521104,  1033, 'Resource Number9');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521105,  1033, 'Resource Number10');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521106,  1033, 'Resource Number11');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521107,  1033, 'Resource Number12');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521108,  1033, 'Resource Number13');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521109,  1033, 'Resource Number14');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521110,  1033, 'Resource Number15');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521111,  1033, 'Resource Number16');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521112,  1033, 'Resource Number17');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521113,  1033, 'Resource Number18');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521114,  1033, 'Resource Number19');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521115,  1033, 'Resource Number20');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521034,  1033, 'Resource Hyperlink');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521035,  1033, 'Resource Hyperlink Address');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521036,  1033, 'Resource Hyperlink SubAddress');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205520924,  1033, 'Resource Notes');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205520899,  1033, 'Resource Group');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205520906,  1033, 'Resource Code');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205520931,  1033, 'Resource Email Address');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521207,  1033, 'Resource Windows User Account');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205520904,  1033, 'Resource Text1');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205520905,  1033, 'Resource Text2');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205520926,  1033, 'Resource Text3');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205520927,  1033, 'Resource Text4');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205520928,  1033, 'Resource Text5');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205520993,  1033, 'Resource Text6');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205520994,  1033, 'Resource Text7');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205520995,  1033, 'Resource Text8');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205520996,  1033, 'Resource Text9');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205520997,  1033, 'Resource Text10');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521121,  1033, 'Resource Text11');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521122,  1033, 'Resource Text12');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521123,  1033, 'Resource Text13');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521124,  1033, 'Resource Text14');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521125,  1033, 'Resource Text15');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521126,  1033, 'Resource Text16');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521127,  1033, 'Resource Text17');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521128,  1033, 'Resource Text18');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521129,  1033, 'Resource Text19');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521130,  1033, 'Resource Text20');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521131,  1033, 'Resource Text21');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521132,  1033, 'Resource Text22');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521133,  1033, 'Resource Text23');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521134,  1033, 'Resource Text24');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521135,  1033, 'Resource Text25');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521136,  1033, 'Resource Text26');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521137,  1033, 'Resource Text27');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521138,  1033, 'Resource Text28');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521139,  1033, 'Resource Text29');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521140,  1033, 'Resource Text30');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205520998,  1033, 'Resource Start1');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205520999,  1033, 'Resource Start2');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521000,  1033, 'Resource Start3');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521001,  1033, 'Resource Start4');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521002,  1033, 'Resource Start5');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521116,  1033, 'Resource Start6');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521117,  1033, 'Resource Start7');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521118,  1033, 'Resource Start8');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521119,  1033, 'Resource Start9');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521120,  1033, 'Resource Start10');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521003,  1033, 'Resource Finish1');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521004,  1033, 'Resource Finish2');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521005,  1033, 'Resource Finish3');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521006,  1033, 'Resource Finish4');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521007,  1033, 'Resource Finish5');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521086,  1033, 'Resource Finish6');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521087,  1033, 'Resource Finish7');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521088,  1033, 'Resource Finish8');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521089,  1033, 'Resource Finish9');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521090,  1033, 'Resource Finish10');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521069,  1033, 'Resource Date1');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521070,  1033, 'Resource Date2');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521071,  1033, 'Resource Date3');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521072,  1033, 'Resource Date4');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521073,  1033, 'Resource Date5');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521074,  1033, 'Resource Date6');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521075,  1033, 'Resource Date7');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521076,  1033, 'Resource Date8');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521077,  1033, 'Resource Date9');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521078,  1033, 'Resource Date10');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521013,  1033, 'Resource Duration1');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521014,  1033, 'Resource Duration2');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521015,  1033, 'Resource Duration3');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521079,  1033, 'Resource Duration4');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521080,  1033, 'Resource Duration5');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521081,  1033, 'Resource Duration6');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521082,  1033, 'Resource Duration7');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521083,  1033, 'Resource Duration8');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521084,  1033, 'Resource Duration9');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521085,  1033, 'Resource Duration10');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521019,  1033, 'Resource Cost1');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521020,  1033, 'Resource Cost2');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521021,  1033, 'Resource Cost3');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521062,  1033, 'Resource Cost4');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521063,  1033, 'Resource Cost5');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521064,  1033, 'Resource Cost6');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521065,  1033, 'Resource Cost7');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521066,  1033, 'Resource Cost8');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521067,  1033, 'Resource Cost9');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521068,  1033, 'Resource Cost10');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521022,  1033, 'Resource Flag10');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521023,  1033, 'Resource Flag1');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521024,  1033, 'Resource Flag2');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521025,  1033, 'Resource Flag3');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521026,  1033, 'Resource Flag4');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521027,  1033, 'Resource Flag5');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521028,  1033, 'Resource Flag6');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521029,  1033, 'Resource Flag7');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521030,  1033, 'Resource Flag8');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521031,  1033, 'Resource Flag9');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521091,  1033, 'Resource Flag11');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521092,  1033, 'Resource Flag12');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521093,  1033, 'Resource Flag13');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521094,  1033, 'Resource Flag14');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521095,  1033, 'Resource Flag15');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521096,  1033, 'Resource Flag16');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521097,  1033, 'Resource Flag17');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521098,  1033, 'Resource Flag18');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521099,  1033, 'Resource Flag19');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521100,  1033, 'Resource Flag20');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521174,  1033, 'Resource Outline Code1');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521176,  1033, 'Resource Outline Code2');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521178,  1033, 'Resource Outline Code3');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521180,  1033, 'Resource Outline Code4');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521182,  1033, 'Resource Outline Code5');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521184,  1033, 'Resource Outline Code6');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521186,  1033, 'Resource Outline Code7');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521188,  1033, 'Resource Outline Code8');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521190,  1033, 'Resource Outline Code9');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 205521192,  1033, 'Resource Outline Code10');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852652,  1033, 'Assignment Number1');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852653,  1033, 'Assignment Number2');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852654,  1033, 'Assignment Number3');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852655,  1033, 'Assignment Number4');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852656,  1033, 'Assignment Number5');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852742,  1033, 'Assignment Number6');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852743,  1033, 'Assignment Number7');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852744,  1033, 'Assignment Number8');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852745,  1033, 'Assignment Number9');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852746,  1033, 'Assignment Number10');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852747,  1033, 'Assignment Number11');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852748,  1033, 'Assignment Number12');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852749,  1033, 'Assignment Number13');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852750,  1033, 'Assignment Number14');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852751,  1033, 'Assignment Number15');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852752,  1033, 'Assignment Number16');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852753,  1033, 'Assignment Number17');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852754,  1033, 'Assignment Number18');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852755,  1033, 'Assignment Number19');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852756,  1033, 'Assignment Number20');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852696,  1033, 'Assignment Hyperlink');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852697,  1033, 'Assignment Hyperlink Address');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852698,  1033, 'Assignment Hyperlink SubAddress');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852623,  1033, 'Assignment Notes');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852632,  1033, 'Assignment Text1');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852633,  1033, 'Assignment Text2');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852634,  1033, 'Assignment Text3');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852635,  1033, 'Assignment Text4');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852636,  1033, 'Assignment Text5');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852637,  1033, 'Assignment Text6');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852638,  1033, 'Assignment Text7');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852639,  1033, 'Assignment Text8');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852640,  1033, 'Assignment Text9');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852641,  1033, 'Assignment Text10');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852762,  1033, 'Assignment Text11');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852763,  1033, 'Assignment Text12');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852764,  1033, 'Assignment Text13');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852765,  1033, 'Assignment Text14');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852766,  1033, 'Assignment Text15');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852767,  1033, 'Assignment Text16');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852768,  1033, 'Assignment Text17');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852769,  1033, 'Assignment Text18');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852770,  1033, 'Assignment Text19');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852771,  1033, 'Assignment Text20');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852772,  1033, 'Assignment Text21');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852773,  1033, 'Assignment Text22');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852774,  1033, 'Assignment Text23');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852775,  1033, 'Assignment Text24');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852776,  1033, 'Assignment Text25');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852777,  1033, 'Assignment Text26');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852778,  1033, 'Assignment Text27');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852779,  1033, 'Assignment Text28');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852780,  1033, 'Assignment Text29');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852781,  1033, 'Assignment Text30');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852642,  1033, 'Assignment Start1');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852643,  1033, 'Assignment Start2');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852644,  1033, 'Assignment Start3');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852645,  1033, 'Assignment Start4');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852646,  1033, 'Assignment Start5');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852757,  1033, 'Assignment Start6');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852758,  1033, 'Assignment Start7');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852759,  1033, 'Assignment Start8');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852760,  1033, 'Assignment Start9');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852761,  1033, 'Assignment Start10');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852647,  1033, 'Assignment Finish1');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852648,  1033, 'Assignment Finish2');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852649,  1033, 'Assignment Finish3');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852650,  1033, 'Assignment Finish4');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852651,  1033, 'Assignment Finish5');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852727,  1033, 'Assignment Finish6');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852728,  1033, 'Assignment Finish7');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852729,  1033, 'Assignment Finish8');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852730,  1033, 'Assignment Finish9');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852731,  1033, 'Assignment Finish10');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852710,  1033, 'Assignment Date1');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852711,  1033, 'Assignment Date2');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852712,  1033, 'Assignment Date3');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852713,  1033, 'Assignment Date4');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852714,  1033, 'Assignment Date5');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852715,  1033, 'Assignment Date6');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852716,  1033, 'Assignment Date7');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852717,  1033, 'Assignment Date8');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852718,  1033, 'Assignment Date9');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852719,  1033, 'Assignment Date10');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852657,  1033, 'Assignment Duration1');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852658,  1033, 'Assignment Duration2');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852659,  1033, 'Assignment Duration3');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852720,  1033, 'Assignment Duration4');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852721,  1033, 'Assignment Duration5');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852722,  1033, 'Assignment Duration6');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852723,  1033, 'Assignment Duration7');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852724,  1033, 'Assignment Duration8');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852725,  1033, 'Assignment Duration9');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852726,  1033, 'Assignment Duration10');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852663,  1033, 'Assignment Cost1');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852664,  1033, 'Assignment Cost2');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852665,  1033, 'Assignment Cost3');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852703,  1033, 'Assignment Cost4');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852704,  1033, 'Assignment Cost5');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852705,  1033, 'Assignment Cost6');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852706,  1033, 'Assignment Cost7');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852707,  1033, 'Assignment Cost8');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852708,  1033, 'Assignment Cost9');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852709,  1033, 'Assignment Cost10');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852666,  1033, 'Assignment Flag10');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852667,  1033, 'Assignment Flag1');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852668,  1033, 'Assignment Flag2');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852669,  1033, 'Assignment Flag3');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852670,  1033, 'Assignment Flag4');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852671,  1033, 'Assignment Flag5');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852672,  1033, 'Assignment Flag6');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852673,  1033, 'Assignment Flag7');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852674,  1033, 'Assignment Flag8');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852675,  1033, 'Assignment Flag9');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852732,  1033, 'Assignment Flag11');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852733,  1033, 'Assignment Flag12');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852734,  1033, 'Assignment Flag13');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852735,  1033, 'Assignment Flag14');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852736,  1033, 'Assignment Flag15');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852737,  1033, 'Assignment Flag16');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852738,  1033, 'Assignment Flag17');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852739,  1033, 'Assignment Flag18');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852740,  1033, 'Assignment Flag19');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 255852741,  1033, 'Assignment Flag20');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 239075346,  1033, 'Dependencies External Predecessor Task Name');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (105, 239075347,  1033, 'Dependencies External Successor Task Name');

insert into MSP_STRING_TYPES (STRING_TYPE_ID, STRING_LANG_ID, STRING_TYPE) values (56, 1033, 'Weekday');

insert into MSP_STRING_TYPES (STRING_TYPE_ID, STRING_LANG_ID, STRING_TYPE) values (57, 1033, 'Display Units');

insert into MSP_STRING_TYPES (STRING_TYPE_ID, STRING_LANG_ID, STRING_TYPE) values (68, 1033, 'Constraint Type');

insert into MSP_STRING_TYPES (STRING_TYPE_ID, STRING_LANG_ID, STRING_TYPE) values (70, 1033, 'Accrual');

insert into MSP_STRING_TYPES (STRING_TYPE_ID, STRING_LANG_ID, STRING_TYPE) values (14, 1033, 'Work Contour Type');

insert into MSP_STRING_TYPES (STRING_TYPE_ID, STRING_LANG_ID, STRING_TYPE) values (3, 1033, 'Link Type');

insert into MSP_STRING_TYPES (STRING_TYPE_ID, STRING_LANG_ID, STRING_TYPE) values (29, 1033, 'Task Type');

insert into MSP_STRING_TYPES (STRING_TYPE_ID, STRING_LANG_ID, STRING_TYPE) values (78, 1033, 'Cost Rate Data Units');

insert into MSP_STRING_TYPES (STRING_TYPE_ID, STRING_LANG_ID, STRING_TYPE) values (81, 1033, 'Workgroup User Type');

insert into MSP_STRING_TYPES (STRING_TYPE_ID, STRING_LANG_ID, STRING_TYPE) values (83, 1033, 'Weekday');

insert into MSP_STRING_TYPES (STRING_TYPE_ID, STRING_LANG_ID, STRING_TYPE) values (84, 1033, 'Weekday');

insert into MSP_STRING_TYPES (STRING_TYPE_ID, STRING_LANG_ID, STRING_TYPE) values (85, 1033, 'Weekday');

insert into MSP_STRING_TYPES (STRING_TYPE_ID, STRING_LANG_ID, STRING_TYPE) values (100, 1033, 'Category Type');

insert into MSP_STRING_TYPES (STRING_TYPE_ID, STRING_LANG_ID, STRING_TYPE) values (101, 1033, 'Schedule From');

insert into MSP_STRING_TYPES (STRING_TYPE_ID, STRING_LANG_ID, STRING_TYPE) values (102, 1033, 'Calendar Working');

insert into MSP_STRING_TYPES (STRING_TYPE_ID, STRING_LANG_ID, STRING_TYPE) values (103, 1033, 'Currency Symbol Position');

insert into MSP_STRING_TYPES (STRING_TYPE_ID, STRING_LANG_ID, STRING_TYPE) values (104, 1033, 'Workgroup Messages');

insert into MSP_STRING_TYPES (STRING_TYPE_ID, STRING_LANG_ID, STRING_TYPE) values (105, 1033, 'Field ID');

insert into MSP_STRING_TYPES (STRING_TYPE_ID, STRING_LANG_ID, STRING_TYPE) values (106, 1033, 'Field Attributes');

insert into MSP_STRING_TYPES (STRING_TYPE_ID, STRING_LANG_ID, STRING_TYPE) values (107, 1033, 'Timephased Contour Type');

insert into MSP_STRING_TYPES (STRING_TYPE_ID, STRING_LANG_ID, STRING_TYPE) values (108, 1033, 'Timephased Data Units ');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (56, 1,  1033, 'Sunday');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (56, 2,  1033, 'Monday');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (56, 3,  1033, 'Tuesday');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (56, 4,  1033, 'Wednesday');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (56, 5,  1033, 'Thursday');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (56, 6,  1033, 'Friday');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (56, 7,  1033, 'Saturday');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (57, 3,  1033, 'm');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (57, 4,  1033, 'em');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (57, 5,  1033, 'h');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (57, 6,  1033, 'eh');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (57, 7,  1033, 'd');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (57, 8,  1033, 'ed');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (57, 9,  1033, 'w');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (57, 10,  1033, 'ew');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (57, 11,  1033, 'mo');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (57, 12,  1033, 'emo');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (57, 19,  1033, '%');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (57, 20,  1033, 'e%');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (57, 21,  1033, '');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (57, 35,  1033, 'm?');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (57, 36,  1033, 'em?');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (57, 37,  1033, 'h?');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (57, 38,  1033, 'eh?');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (57, 39,  1033, 'd?');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (57, 40,  1033, 'ed?');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (57, 41,  1033, 'w?');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (57, 42,  1033, 'ew?');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (57, 43,  1033, 'mo?');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (57, 44,  1033, 'emo?');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (57, 51,  1033, '%?');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (57, 52,  1033, 'e%?');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (57, 53,  1033, '');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (68, 0,  1033, 'As Soon As Possible');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (68, 1,  1033, 'As Late As Possible');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (68, 2,  1033, 'Must Start On');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (68, 3,  1033, 'Must Finish On');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (68, 4,  1033, 'Start No Earlier Than');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (68, 5,  1033, 'Start No Later Than');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (68, 6,  1033, 'Finish No Earlier Than');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (68, 7,  1033, 'Finish No Later Than');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (70, 1,  1033, 'Start');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (70, 2,  1033, 'End');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (14, 0,  1033, 'Flat');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (14, 1,  1033, 'Back Loaded');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (14, 2,  1033, 'Front Loaded');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (14, 3,  1033, 'Double Peak');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (14, 4,  1033, 'Early Peak');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (14, 5,  1033, 'Late Peak');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (14, 6,  1033, 'Bell');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (14, 7,  1033, 'Turtle');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (14, 8,  1033, 'Contoured');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (3, 0,  1033, 'FF');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (3, 1,  1033, 'FS');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (3, 2,  1033, 'SF');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (3, 3,  1033, 'SS');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (29, 0,  1033, 'Fixed Units');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (29, 1,  1033, 'Fixed Duration');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (29, 2,  1033, 'Fixed Work');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (78, 1,  1033, 'm');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (78, 2,  1033, 'h');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (78, 3,  1033, 'd');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (78, 4,  1033, 'w');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (78, 5,  1033, 'mo');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (78, 7,  1033, 'y');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (81, 0,  1033, 'Default');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (81, 1,  1033, 'None');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (81, 2,  1033, 'Email');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (81, 3,  1033, 'Web');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (83, 1,  1033, 'Su');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (83, 2,  1033, 'Mo');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (83, 3,  1033, 'Tu');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (83, 4,  1033, 'We');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (83, 5,  1033, 'Th');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (83, 6,  1033, 'Fr');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (83, 7,  1033, 'Sa');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (84, 1,  1033, '(Su)');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (84, 2,  1033, '(Mo)');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (84, 3,  1033, '(Tu)');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (84, 4,  1033, '(We)');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (84, 5,  1033, '(Th)');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (84, 6,  1033, '(Fr)');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (84, 7,  1033, '(Sa)');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (85, 1,  1033, 'Sunday');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (85, 2,  1033, 'Monday');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (85, 3,  1033, 'Tuesday');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (85, 4,  1033, 'Wednesday');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (85, 5,  1033, 'Thursday');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (85, 6,  1033, 'Friday');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (85, 7,  1033, 'Saturday');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (100, 0,  1033, 'Task');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (100, 1,  1033, 'Resource');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (100, 2,  1033, 'Calendar');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (100, 3,  1033, 'Assignment');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (100, 4,  1033, 'Dependencies');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (101, 0,  1033, 'Schedule From Project Finish');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (101, 1,  1033, 'Schedule From Project Start');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (102, 0,  1033, 'Non-Working');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (102, 1,  1033, 'Working');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (102, 2,  1033, 'Default');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (103, 0,  1033, 'Before');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (103, 1,  1033, 'After');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (103, 2,  1033, 'Before with Space');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (103, 3,  1033, 'After with Space');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (104, 0,  1033, 'Default');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (104, 1,  1033, 'None');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (104, 2,  1033, 'Email');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (104, 3,  1033, 'Web');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (106, 1,  1033, 'Outline code and WBS mask');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (106, 2,  1033, 'Only allow outline codes listed in the lookup table');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (106, 3,  1033, 'Only allow new outline codes with values at all levels of mask');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (106, 4,  1033, 'Verify uniqueness of new WBS codes');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (106, 5,  1033, 'WBS Prefix');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (106, 6,  1033, 'Generate WBS code for new tasks');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (106, 7,  1033, 'Field Alias');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (106, 8,  1033, 'Custom Field Formula');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (106, 9,  1033, 'Sharer File Names');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (107, 200,  1033, 'Assignment Remaining Work');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (107, 201,  1033, 'Assignment Actual Work');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (107, 202,  1033, 'Assignment Actual Overtime Work');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (107, 203,  1033, 'Assignment Baseline Work');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (107, 204,  1033, 'Assignment Baseline Cost');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (107, 205,  1033, 'Assignment Actual Cost');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (107, 206,  1033, 'Resource Baseline Work');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (107, 207,  1033, 'Resource Baseline Cost');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (107, 208,  1033, 'Task Baseline Work');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (107, 209,  1033, 'Task Baseline Cost');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (107, 210,  1033, 'Task Percent Complete');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (56, 0,  1033, 'Exception');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (108, 0,  1033, 'm');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (108, 1,  1033, 'h');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (108, 2,  1033, 'd');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (108, 3,  1033, 'w');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (108, 5,  1033, 'mo');

insert into MSP_CONVERSIONS (STRING_TYPE_ID, CONV_VALUE, CONV_LANG_ID, CONV_STRING) values (108, 8,  1033, 'y');
